@@ -27,8 +27,7 @@
 
 #include "baghiraconfig.h"
 #include "configdialog.h"
-#include "preview.h"
-//#include "../images.h"
+#include "pixmaps.h"
 
 //////////////////////////////////////////////////////////////////////////////
 // BaghiraConfig Class                                                        //
@@ -58,18 +57,19 @@ BaghiraConfig::BaghiraConfig(KConfig*, QWidget* parent)
             
     // connections
     connect(dialog_->titlealign, SIGNAL(clicked(int)), SIGNAL(changed()));
-    connect(dialog_->drawComicFrame, SIGNAL(toggled(bool)), SIGNAL(changed()));            
+    connect(dialog_->drawComicFrame, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->addAutoSpacing, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->bigHandler, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->allowEasyClosing, SIGNAL(toggled(bool)), SIGNAL(changed()));            
-    connect(dialog_->FollowStyle, SIGNAL(toggled(bool)), SIGNAL(changed()));
+    connect(dialog_->allowEasyClosing, SIGNAL(toggled(bool)), SIGNAL(changed()));
+    connect(dialog_->ResizeGrip, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->maxResizable, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->fullSpec, SIGNAL(toggled(bool)), SIGNAL(changed()));
+    connect(dialog_->noModalDeco, SIGNAL(toggled(bool)), SIGNAL(changed()));
+    connect(dialog_->delAppname, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->defaultMode, SIGNAL(activated(int)),  SIGNAL(changed()));
-    connect(dialog_->minTH, SIGNAL(valueChanged(int)), SIGNAL(changed()));        
+    connect(dialog_->minTH, SIGNAL(valueChanged(int)), SIGNAL(changed()));
     
     connect(dialog_->activeColor1_J, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->activeColor2_J, SIGNAL(clicked()), SIGNAL(changed()));            
+    connect(dialog_->activeColor2_J, SIGNAL(clicked()), SIGNAL(changed()));
     connect(dialog_->inactiveColor1_J, SIGNAL(clicked()), SIGNAL(changed()));
     connect(dialog_->inactiveColor2_J, SIGNAL(clicked()), SIGNAL(changed()));
     connect(dialog_->buttonStyle_J, SIGNAL(activated(int)), SIGNAL(changed()));
@@ -77,14 +77,15 @@ BaghiraConfig::BaghiraConfig(KConfig*, QWidget* parent)
     connect(dialog_->shapeUR_J, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->shapeLL_J, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->shapeLR_J, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->drawIcon_J, SIGNAL(toggled(bool)), SIGNAL(changed()));    
+    connect(dialog_->drawIcon_J, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->titleeffect_J, SIGNAL(activated(int)),  SIGNAL(changed()));
     connect(dialog_->i_titleeffect_J, SIGNAL(activated(int)), SIGNAL(changed()));
     connect(dialog_->_3DImpact_J, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-    connect(dialog_->LineImpact_J, SIGNAL(valueChanged(int)), SIGNAL(changed()));          
+    connect(dialog_->LineImpact_J, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   connect(dialog_->borderSize_J, SIGNAL(valueChanged(int)), SIGNAL(changed()));
             
     connect(dialog_->activeColor1_P, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->activeColor2_P, SIGNAL(clicked()), SIGNAL(changed()));            
+    connect(dialog_->activeColor2_P, SIGNAL(clicked()), SIGNAL(changed()));
     connect(dialog_->inactiveColor1_P, SIGNAL(clicked()), SIGNAL(changed()));
     connect(dialog_->inactiveColor2_P, SIGNAL(clicked()), SIGNAL(changed()));
     connect(dialog_->buttonStyle_P, SIGNAL(activated(int)), SIGNAL(changed()));
@@ -92,14 +93,15 @@ BaghiraConfig::BaghiraConfig(KConfig*, QWidget* parent)
     connect(dialog_->shapeUR_P, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->shapeLL_P, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->shapeLR_P, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->drawIcon_P, SIGNAL(toggled(bool)), SIGNAL(changed()));    
+    connect(dialog_->drawIcon_P, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->titleeffect_P, SIGNAL(activated(int)), SIGNAL(changed()));
     connect(dialog_->i_titleeffect_P, SIGNAL(activated(int)), SIGNAL(changed()));
     connect(dialog_->_3DImpact_P, SIGNAL(valueChanged(int)), SIGNAL(changed()));
     connect(dialog_->LineImpact_P, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   connect(dialog_->borderSize_P, SIGNAL(valueChanged(int)), SIGNAL(changed()));
             
     connect(dialog_->activeColor1_B, SIGNAL(clicked()), SIGNAL(changed()));
-    connect(dialog_->activeColor2_B, SIGNAL(clicked()), SIGNAL(changed()));            
+    connect(dialog_->activeColor2_B, SIGNAL(clicked()), SIGNAL(changed()));
     connect(dialog_->inactiveColor1_B, SIGNAL(clicked()), SIGNAL(changed()));
     connect(dialog_->inactiveColor2_B, SIGNAL(clicked()), SIGNAL(changed()));
     connect(dialog_->buttonStyle_B, SIGNAL(activated(int)), SIGNAL(changed()));
@@ -107,11 +109,23 @@ BaghiraConfig::BaghiraConfig(KConfig*, QWidget* parent)
     connect(dialog_->shapeUR_B, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->shapeLL_B, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->shapeLR_B, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(dialog_->drawIcon_B, SIGNAL(toggled(bool)), SIGNAL(changed()));    
+    connect(dialog_->drawIcon_B, SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(dialog_->titleeffect_B, SIGNAL(activated(int)),  SIGNAL(changed()));
     connect(dialog_->i_titleeffect_B, SIGNAL(activated(int)), SIGNAL(changed()));
     connect(dialog_->_3DImpact_B, SIGNAL(valueChanged(int)), SIGNAL(changed()));
     connect(dialog_->LineImpact_B, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   connect(dialog_->borderSize_B, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   
+   connect(dialog_->activeColor1_T, SIGNAL(clicked()), SIGNAL(changed()));
+   connect(dialog_->activeColor2_T, SIGNAL(clicked()), SIGNAL(changed()));            
+   connect(dialog_->buttonStyle_T, SIGNAL(activated(int)), SIGNAL(changed()));
+   connect(dialog_->shapeUL_T, SIGNAL(toggled(bool)), SIGNAL(changed()));
+   connect(dialog_->shapeUR_T, SIGNAL(toggled(bool)), SIGNAL(changed()));
+   connect(dialog_->shapeLL_T, SIGNAL(toggled(bool)), SIGNAL(changed()));
+   connect(dialog_->shapeLR_T, SIGNAL(toggled(bool)), SIGNAL(changed()));
+   connect(dialog_->drawIcon_T, SIGNAL(toggled(bool)), SIGNAL(changed()));    
+   connect(dialog_->_3DImpact_T, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+   connect(dialog_->borderSize_T, SIGNAL(valueChanged(int)), SIGNAL(changed()));
 //     config_->endGroup();
 
 }
@@ -143,19 +157,20 @@ void BaghiraConfig::load(KConfig*)
     if (button) button->setChecked(true);
 
     dialog_->minTH->setValue(config_->readNumEntry("minimumTitleHeight",18));
-    dialog_->bigHandler->setChecked(config_->readBoolEntry("BigHandler",false));
-    dialog_->FollowStyle->setChecked(config_->readBoolEntry("FollowStyle",false));
+    dialog_->ResizeGrip->setChecked(config_->readBoolEntry("ResizeGrip",false));
     dialog_->allowEasyClosing->setChecked(config_->readBoolEntry("allowEasyClosing",false));
     dialog_->drawComicFrame->setChecked(config_->readBoolEntry("DrawComicFrame",false));
     dialog_->maxResizable->setChecked(config_->readBoolEntry("MaxResizable",false));
     dialog_->fullSpec->setChecked(config_->readBoolEntry("FullSpec",false));
     dialog_->addAutoSpacing->setChecked(config_->readBoolEntry("AddAutoSpacing",true));
     dialog_->defaultMode->setCurrentItem(config_->readNumEntry("defaultMode",1));
+    dialog_->noModalDeco->setChecked(config_->readBoolEntry("NoModalDeco",false));
+    dialog_->delAppname->setChecked(config_->readBoolEntry("RemoveAppname",false));
         
-    dialog_->activeColor1_J->setColor(QColor((unsigned int)config_->readNumEntry("activeColor1_1",QColor(250,250,250).rgb())));
-    dialog_->inactiveColor1_J->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor1_1",QColor(216,231,247).rgb())));
-    dialog_->activeColor2_J->setColor(QColor((unsigned int)config_->readNumEntry("activeColor2_1",QColor(220,220,220).rgb())));
-    dialog_->inactiveColor2_J->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor2_1",QColor(212,220,235).rgb())));
+    dialog_->activeColor1_J->setColor(QColor((unsigned int)config_->readNumEntry("activeColor1_1",QColor(255,255,255).rgb())));
+    dialog_->inactiveColor1_J->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor1_1",QColor(204,214,230).rgb())));
+   dialog_->activeColor2_J->setColor(QColor((unsigned int)config_->readNumEntry("activeColor2_1",QColor(238,234,238).rgb())));
+    dialog_->inactiveColor2_J->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor2_1",QColor(194,196,211).rgb())));
     dialog_->buttonStyle_J->setCurrentItem(config_->readNumEntry("ButtonStyle_1",1));
     dialog_->titleeffect_J->setCurrentItem(config_->readNumEntry("TitleEffect_1", 1));
     dialog_->i_titleeffect_J->setCurrentItem(config_->readNumEntry("inactiveTitleEffect_1", 1));
@@ -166,11 +181,12 @@ void BaghiraConfig::load(KConfig*)
     dialog_->drawIcon_J->setChecked(config_->readBoolEntry("drawIcon_1",true));
     dialog_->_3DImpact_J->setValue(config_->readNumEntry("3DImpact_1",20));
     dialog_->LineImpact_J->setValue(config_->readNumEntry("LineImpact_1",40));
+   dialog_->borderSize_J->setValue(config_->readNumEntry("BorderSize_1",0));
     
     dialog_->activeColor1_P->setColor(QColor((unsigned int)config_->readNumEntry("activeColor1_2",QColor(238,238,238).rgb())));
-    dialog_->inactiveColor1_P->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor1_2",QColor(230,230,230).rgb())));
-    dialog_->activeColor2_P->setColor(QColor((unsigned int)config_->readNumEntry("activeColor2_2",QColor(192,192,192).rgb())));
-    dialog_->inactiveColor2_P->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor2_2",QColor(202,202,202).rgb())));
+    dialog_->inactiveColor1_P->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor1_2",QColor(246,242,246).rgb())));
+    dialog_->activeColor2_P->setColor(QColor((unsigned int)config_->readNumEntry("activeColor2_2",QColor(205,202,205).rgb())));
+    dialog_->inactiveColor2_P->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor2_2",QColor(238,238,238).rgb())));
     dialog_->buttonStyle_P->setCurrentItem(config_->readNumEntry("ButtonStyle_2",0));
     dialog_->titleeffect_P->setCurrentItem(config_->readNumEntry("TitleEffect_2", 0));
     dialog_->i_titleeffect_P->setCurrentItem(config_->readNumEntry("inactiveTitleEffect_2", 0));
@@ -181,11 +197,12 @@ void BaghiraConfig::load(KConfig*)
     dialog_->drawIcon_P->setChecked(config_->readBoolEntry("drawIcon_2",true));
     dialog_->_3DImpact_P->setValue(config_->readNumEntry("3DImpact_2",20));
     dialog_->LineImpact_P->setValue(config_->readNumEntry("LineImpact_2",40));
+   dialog_->borderSize_P->setValue(config_->readNumEntry("BorderSize_2",0));
     
-    dialog_->activeColor1_B->setColor(QColor((unsigned int)config_->readNumEntry("activeColor1_3",QColor(238,238,238).rgb())));
-    dialog_->inactiveColor1_B->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor1_3",QColor(230,230,230).rgb())));
-    dialog_->activeColor2_B->setColor(QColor((unsigned int)config_->readNumEntry("activeColor2_3",QColor(192,192,192).rgb())));
-    dialog_->inactiveColor2_B->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor2_3",QColor(202,202,202).rgb())));
+    dialog_->activeColor1_B->setColor(QColor((unsigned int)config_->readNumEntry("activeColor1_3",QColor(202,202,202).rgb())));
+    dialog_->inactiveColor1_B->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor1_3",QColor(200,200,200).rgb())));
+    dialog_->activeColor2_B->setColor(QColor((unsigned int)config_->readNumEntry("activeColor2_3",QColor(150,150,150).rgb())));
+   dialog_->inactiveColor2_B->setColor(QColor((unsigned int)config_->readNumEntry("inactiveColor2_3",QColor(150,150,150).rgb())));
     dialog_->buttonStyle_B->setCurrentItem(config_->readNumEntry("ButtonStyle_3",0));
     dialog_->titleeffect_B->setCurrentItem(config_->readNumEntry("TitleEffect_3", 4));
     dialog_->i_titleeffect_B->setCurrentItem(config_->readNumEntry("inactiveTitleEffect_3", 4));
@@ -195,7 +212,19 @@ void BaghiraConfig::load(KConfig*)
     dialog_->shapeLR_B->setChecked(config_->readBoolEntry("ShapeLR_3",true));
     dialog_->drawIcon_B->setChecked(config_->readBoolEntry("drawIcon_3",true));
     dialog_->_3DImpact_B->setValue(config_->readNumEntry("3DImpact_3",20));
-    dialog_->LineImpact_B->setValue(config_->readNumEntry("LineImpact_3",40));
+    dialog_->LineImpact_B->setValue(config_->readNumEntry("LineImpact_3",0));
+   dialog_->borderSize_B->setValue(config_->readNumEntry("BorderSize_3",6));
+   
+   dialog_->activeColor1_T->setColor(QColor((unsigned int)config_->readNumEntry("activeColor1_4",QColor(238,238,238).rgb())));
+   dialog_->activeColor2_T->setColor(QColor((unsigned int)config_->readNumEntry("activeColor2_4",QColor(205,202,205).rgb())));
+   dialog_->buttonStyle_T->setCurrentItem(config_->readNumEntry("ButtonStyle_4",0));
+   dialog_->shapeUL_T->setChecked(config_->readBoolEntry("ShapeUL_4",true));
+   dialog_->shapeUR_T->setChecked(config_->readBoolEntry("ShapeUR_4",true));
+   dialog_->shapeLL_T->setChecked(config_->readBoolEntry("ShapeLL_4",false));
+   dialog_->shapeLR_T->setChecked(config_->readBoolEntry("ShapeLR_4",false));
+   dialog_->drawIcon_T->setChecked(config_->readBoolEntry("drawIcon_4",true));
+   dialog_->_3DImpact_T->setValue(config_->readNumEntry("3DImpact_4",20));
+   dialog_->borderSize_T->setValue(config_->readNumEntry("BorderSize_4",0));
    
     buttonDialog_->inactiveColor->setColor(QColor((unsigned int)config_->readNumEntry("InactiveButtonColor", QColor(255,255,255).rgb())));
     buttonDialog_->closeColor->setColor(QColor((unsigned int)config_->readNumEntry("CloseButtonColor", QColor(200,85,70).rgb())));
@@ -227,13 +256,14 @@ void BaghiraConfig::save(KConfig*)
     if (button) config_->writeEntry("TitleAlignment", QString(button->name()));
     config_->writeEntry("DrawComicFrame", dialog_->drawComicFrame->isChecked());
     config_->writeEntry("AddAutoSpacing", dialog_->addAutoSpacing->isChecked());
-    config_->writeEntry("FollowStyle", dialog_->FollowStyle->isChecked());
-    config_->writeEntry("BigHandler", dialog_->bigHandler->isChecked());
+    config_->writeEntry("ResizeGrip", dialog_->ResizeGrip->isChecked());
     config_->writeEntry("allowEasyClosing", dialog_->allowEasyClosing->isChecked());
     config_->writeEntry("MaxResizable", dialog_->maxResizable->isChecked());
     config_->writeEntry("FullSpec", dialog_->fullSpec->isChecked());
     config_->writeEntry("defaultMode", dialog_->defaultMode->currentItem());
     config_->writeEntry("minimumTitleHeight", dialog_->minTH->value());
+    config_->writeEntry("NoModalDeco", dialog_->noModalDeco->isChecked());
+    config_->writeEntry("RemoveAppname", dialog_->delAppname->isChecked());
        
     config_->writeEntry("activeColor1_1", (int)dialog_->activeColor1_J->color().rgb());
     config_->writeEntry("activeColor2_1", (int)dialog_->activeColor2_J->color().rgb());
@@ -249,6 +279,7 @@ void BaghiraConfig::save(KConfig*)
     config_->writeEntry("drawIcon_1", dialog_->drawIcon_J->isChecked());
     config_->writeEntry("3DImpact_1", dialog_->_3DImpact_J->value());
     config_->writeEntry("LineImpact_1", dialog_->LineImpact_J->value());
+   config_->writeEntry("BorderSize_1", dialog_->borderSize_J->value());
     
     config_->writeEntry("activeColor1_2", (int)dialog_->activeColor1_P->color().rgb());
     config_->writeEntry("activeColor2_2", (int)dialog_->activeColor2_P->color().rgb());
@@ -264,6 +295,7 @@ void BaghiraConfig::save(KConfig*)
     config_->writeEntry("drawIcon_2", dialog_->drawIcon_P->isChecked());
     config_->writeEntry("3DImpact_2", dialog_->_3DImpact_P->value());
     config_->writeEntry("LineImpact_2", dialog_->LineImpact_P->value());
+   config_->writeEntry("BorderSize_2", dialog_->borderSize_P->value());
     
     config_->writeEntry("activeColor1_3", (int)dialog_->activeColor1_B->color().rgb());
     config_->writeEntry("activeColor2_3", (int)dialog_->activeColor2_B->color().rgb());
@@ -279,6 +311,18 @@ void BaghiraConfig::save(KConfig*)
     config_->writeEntry("drawIcon_3", dialog_->drawIcon_B->isChecked());
     config_->writeEntry("3DImpact_3", dialog_->_3DImpact_B->value());
     config_->writeEntry("LineImpact_3", dialog_->LineImpact_B->value());
+   config_->writeEntry("BorderSize_3", dialog_->borderSize_B->value());
+   
+   config_->writeEntry("activeColor1_4", (int)dialog_->activeColor1_T->color().rgb());
+   config_->writeEntry("activeColor2_4", (int)dialog_->activeColor2_T->color().rgb());
+   config_->writeEntry("ButtonStyle_4", dialog_->buttonStyle_T->currentItem());
+   config_->writeEntry("ShapeUL_4", dialog_->shapeUL_T->isChecked());
+   config_->writeEntry("ShapeUR_4", dialog_->shapeUR_T->isChecked());
+   config_->writeEntry("ShapeLL_4", dialog_->shapeLL_T->isChecked());
+   config_->writeEntry("ShapeLR_4", dialog_->shapeLR_T->isChecked());    
+   config_->writeEntry("drawIcon_4", dialog_->drawIcon_T->isChecked());
+   config_->writeEntry("3DImpact_4", dialog_->_3DImpact_T->value());
+   config_->writeEntry("BorderSize_4", dialog_->borderSize_T->value());
     
     if (buttonDialog_->save){
     config_->writeEntry("InactiveButtonColor", (int)buttonDialog_->inactiveColor->Color().rgb());
@@ -307,20 +351,21 @@ void BaghiraConfig::defaults()
 {
     QRadioButton *button = (QRadioButton*)dialog_->titlealign->child("AlignHCenter");
     if (button) button->setChecked(true);
-    dialog_->bigHandler->setChecked(false);
     dialog_->allowEasyClosing->setChecked(false);
     dialog_->minTH->setValue(22);
-    dialog_->FollowStyle->setChecked(true);
+    dialog_->ResizeGrip->setChecked(false);
     dialog_->drawComicFrame->setChecked(false);
     dialog_->addAutoSpacing->setChecked(true);
     dialog_->maxResizable->setChecked(false);
     dialog_->fullSpec->setChecked(false);
     dialog_->defaultMode->setCurrentItem(1);
-    
-   dialog_->activeColor1_J->setColor(QColor(250,250,250));
-   dialog_->activeColor1_J->setColor(QColor(216,231,247));
-   dialog_->activeColor1_J->setColor(QColor(220,220,220));
-   dialog_->activeColor1_J->setColor(QColor(212,220,235));
+   dialog_->noModalDeco->setChecked(false);
+   dialog_->delAppname->setChecked(false);
+
+   dialog_->activeColor1_J->setColor(QColor(255,255,255));
+   dialog_->inactiveColor1_J->setColor(QColor(204,214,230));
+   dialog_->activeColor2_J->setColor(QColor(238,234,238));
+   dialog_->inactiveColor2_J->setColor(QColor(194,196,211));
    dialog_->buttonStyle_J->setCurrentItem(1);
    dialog_->titleeffect_J->setCurrentItem(1);
    dialog_->i_titleeffect_J->setCurrentItem(1);
@@ -331,11 +376,12 @@ void BaghiraConfig::defaults()
    dialog_->drawIcon_J->setChecked(true);
    dialog_->_3DImpact_J->setValue(20);
    dialog_->LineImpact_J->setValue(40);
+   dialog_->borderSize_J->setValue(0);
    
    dialog_->activeColor1_P->setColor(QColor(238,238,238));
-   dialog_->activeColor1_P->setColor(QColor(230,230,230));
-   dialog_->activeColor1_P->setColor(QColor(192,192,192));
-   dialog_->activeColor1_P->setColor(QColor(202,202,202));
+   dialog_->inactiveColor1_P->setColor(QColor(246,242,246));
+   dialog_->activeColor2_P->setColor(QColor(205,202,205));
+   dialog_->inactiveColor2_P->setColor(QColor(238,238,238));
    dialog_->buttonStyle_P->setCurrentItem(0);
    dialog_->titleeffect_P->setCurrentItem(0);
    dialog_->i_titleeffect_P->setCurrentItem(0);
@@ -346,11 +392,12 @@ void BaghiraConfig::defaults()
    dialog_->drawIcon_P->setChecked(true);
    dialog_->_3DImpact_P->setValue(20);
    dialog_->LineImpact_P->setValue(30);
+   dialog_->borderSize_P->setValue(0);
    
-   dialog_->activeColor1_B->setColor(QColor(238,238,238));
-   dialog_->activeColor1_B->setColor(QColor(230,230,230));
-   dialog_->activeColor1_B->setColor(QColor(192,192,192));
-   dialog_->activeColor1_B->setColor(QColor(202,202,202));
+   dialog_->activeColor1_B->setColor(QColor(210,210,210));
+   dialog_->inactiveColor1_B->setColor(QColor(200,200,200));
+   dialog_->activeColor2_B->setColor(QColor(150,150,150));
+   dialog_->inactiveColor2_B->setColor(QColor(140,140,140));
    dialog_->buttonStyle_B->setCurrentItem(0);
    dialog_->titleeffect_B->setCurrentItem(4);
    dialog_->i_titleeffect_B->setCurrentItem(4);
@@ -361,12 +408,35 @@ void BaghiraConfig::defaults()
    dialog_->drawIcon_B->setChecked(true);
    dialog_->_3DImpact_B->setValue(20);
    dialog_->LineImpact_B->setValue(0);
+   dialog_->borderSize_B->setValue(6);
+   
+   dialog_->activeColor1_T->setColor(QColor(238,238,238));
+   dialog_->activeColor2_T->setColor(QColor(211,208,211));
+   dialog_->buttonStyle_T->setCurrentItem(0);
+   dialog_->shapeUL_T->setChecked(true);
+   dialog_->shapeUR_T->setChecked(true);
+   dialog_->shapeLL_T->setChecked(false);
+   dialog_->shapeLR_T->setChecked(false);
+   dialog_->drawIcon_T->setChecked(true);
+   dialog_->_3DImpact_T->setValue(20);
+   dialog_->borderSize_T->setValue(0);
    
 //   buttonDialog_->defaults();
 
     
 }   
 
+enum ColorPresets{Aqua = 0, Graphite, GraphiteDark, NUMBEROFCOLORS};
+
+const char * presetColorName[NUMBEROFCOLORS] = {"Aqua", "Graphite", "Graphite (Dark)" };
+
+typedef int ColorTable[10][3];
+
+const int aquaPreset[10][3] = {{255,255,255},{200,85,70},{230,155,40},{121,180,54},{74,140,242},{0,0,0},{74,140,242},{74,140,242},{74,140,242},{74,140,242}};
+const int graphitePreset[10][3] = {{255,255,255},{130,170,190},{130,170,190},{130,170,190},{130,170,190},{0,0,0},{130,170,190},{130,170,190},{130,170,190},{130,170,190}};
+const int graphiteDarkPreset[10][3] = {{255,255,255},{103,118,134},{103,118,134},{103,118,134},{103,118,134},{0,0,0},{103,118,134},{103,118,134},{103,118,134},{103,118,134}};
+const ColorTable* presetColors[NUMBEROFCOLORS] = {&aquaPreset, &graphitePreset, &graphiteDarkPreset};
+
 
 ButtonColors::ButtonColors(QWidget *parent, const char * name) : QDialog(parent, name){
     save = false;
@@ -393,14 +463,16 @@ ButtonColors::ButtonColors(QWidget *parent, const char * name) : QDialog(parent,
     tmpPix = QPixmap(uic_findImage("preview-menu"));
     menuButton = new AquariusButton(tmpPix,this, "Menu Button");
     buttonLayout->addWidget(menuButton);
-    tmpPix = QPixmap(uic_findImage("help"));
+    tmpPix = QPixmap(uic_findImage("icon_help"));
     helpButton = new AquariusButton(tmpPix,this, "Help Button");
     buttonLayout->addWidget(helpButton);
     
     
     twoButts = new QHBoxLayout(0,0,6);
-    defaults_ = new QPushButton("Load Defaults", this);
-    twoButts->addWidget(defaults_);
+    presets_ = new QComboBox(this);
+    for (int i = 0; i < NUMBEROFCOLORS; i++)
+        presets_->insertItem ( presetColorName[i], i );
+    twoButts->addWidget(presets_);
     cancel = new QPushButton("Cancel", this);
     cancel->setDefault( true );
     twoButts->addWidget(cancel);
@@ -411,7 +483,7 @@ ButtonColors::ButtonColors(QWidget *parent, const char * name) : QDialog(parent,
     
     layout->addLayout(buttonLayout,0,1);
     
-    pickerLayout = new QVBoxLayout(0,0,6);
+    pickerLayout = new QVBoxLayout(0,0,6,0);
     
     indicator = new QLabel(inactiveButton->name(), this);
     indicator->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter | Qt::ExpandTabs);
@@ -452,12 +524,14 @@ ButtonColors::ButtonColors(QWidget *parent, const char * name) : QDialog(parent,
     pickerLayout->addWidget(shadeColor);
     shadeColor->hide();
     
+    indicator->lower();
+    
     layout->addLayout(pickerLayout,0,0);
     
     resize( QSize(485, 177).expandedTo(minimumSizeHint()) );
     clearWState( WState_Polished );
     
-    connect(defaults_,SIGNAL(clicked()), this, SLOT(defaults()));
+    connect(presets_,SIGNAL(activated(int)), this, SLOT(setColorGroup(int)));
     connect(ok, SIGNAL(clicked()), this, SLOT(setSave()));
     connect(ok, SIGNAL(clicked()), this, SLOT(close()) );
     connect(ok, SIGNAL(clicked()), this, SLOT(init()) );
@@ -491,17 +565,17 @@ ButtonColors::ButtonColors(QWidget *parent, const char * name) : QDialog(parent,
 ButtonColors::~ButtonColors(){
 }
 
-void ButtonColors::defaults(){   
-    inactiveColor->setColor(QColor(255,255,255).rgb());
-    closeColor->setColor(QColor(200,85,70).rgb());
-    minColor->setColor(QColor(230,155,40).rgb());
-    maxColor->setColor(QColor(121,180,54).rgb());
-    menuColor->setColor(QColor(74,140,242).rgb());
-    helpColor->setColor(QColor(0,0,0).rgb());
-    stickyColor->setColor(QColor(74,140,242).rgb());
-    aboveColor->setColor(QColor(74,140,242).rgb());
-    behindColor->setColor(QColor(74,140,242).rgb());
-    shadeColor->setColor(QColor(74,140,242).rgb());
+void ButtonColors::setColorGroup(int i){
+    inactiveColor->setColor(QColor((*presetColors[i])[0][0],(*presetColors[i])[0][1],(*presetColors[i])[0][2]).rgb());
+    closeColor->setColor(QColor((*presetColors[i])[1][0],(*presetColors[i])[1][1],(*presetColors[i])[1][2]).rgb());
+    minColor->setColor(QColor((*presetColors[i])[2][0],(*presetColors[i])[2][1],(*presetColors[i])[2][2]).rgb());
+    maxColor->setColor(QColor((*presetColors[i])[3][0],(*presetColors[i])[3][1],(*presetColors[i])[3][2]).rgb());
+    menuColor->setColor(QColor((*presetColors[i])[4][0],(*presetColors[i])[4][1],(*presetColors[i])[4][2]).rgb());
+    helpColor->setColor(QColor((*presetColors[i])[5][0],(*presetColors[i])[5][1],(*presetColors[i])[5][2]).rgb());
+    stickyColor->setColor(QColor((*presetColors[i])[6][0],(*presetColors[i])[6][1],(*presetColors[i])[6][2]).rgb());
+    aboveColor->setColor(QColor((*presetColors[i])[7][0],(*presetColors[i])[7][1],(*presetColors[i])[7][2]).rgb());
+    behindColor->setColor(QColor((*presetColors[i])[8][0],(*presetColors[i])[8][1],(*presetColors[i])[8][2]).rgb());
+    shadeColor->setColor(QColor((*presetColors[i])[9][0],(*presetColors[i])[9][1],(*presetColors[i])[9][2]).rgb());
 }
 
 void ButtonColors::setPicker(ColorPicker *picker){
